16.142. cdist-type__update_alternatives(7) — cdist 4.10.11 documentation

# 16.142. cdist-type__update_alternatives(7)

## 16.142.1. NAME

cdist-type__update_alternatives - Configure alternatives

## 16.142.2. DESCRIPTION

On Debian and alike systems update-alternatives(1) can be used to setup alternatives for various programs. One of the most common used targets is the "editor".

## 16.142.3. REQUIRED PARAMETERS

path
  Use this path for the given alternative

## 16.142.4. EXAMPLES

    # Setup vim as the default editor
    __update_alternatives editor --path /usr/bin/vim.basic

## 16.142.5. SEE ALSO

cdist-type__debconf_set_selections(7), update-alternatives(8)

## 16.142.6. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.142.7. COPYING

Copyright (C) 2013 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.